package cn.iocoder.yudao.module.shipment.listener;

import cn.iocoder.yudao.framework.apollo.core.event.box.BoxCheckOrderRemoveLadingBillEvent;
import cn.iocoder.yudao.framework.apollo.core.event.box.BoxCheckOrderSchedulingEvent;
import cn.iocoder.yudao.module.shipment.dal.dataobject.BoxDO;
import cn.iocoder.yudao.module.shipment.service.box.BoxService;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;

import java.util.Collections;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.order.enums.ErrorCodeConstants.WAREHOUSE_IN_BOX_EXCEPTION;

/**
 * 当订单修改审批通过后，需要对已制作的提单进行重置
 *
 * @author zhengYi
 */
@Component("BoxOrderUpdateRemoveLadingBillListener")
@AllArgsConstructor
@Slf4j
public class BoxOrderUpdateRemoveLadingBillListener {

    private final BoxService boxService;

    /**
     * 当订单修改审批通过后，需要对已制作的提单进行重置
     *
     * @param event 订单id
     */
    @EventListener(BoxCheckOrderRemoveLadingBillEvent.class)
    public void removeLadingBill(BoxCheckOrderRemoveLadingBillEvent event) {
        Long orderId = event.getOrderId();
        log.info("重置提单订单 orderId={}", orderId);
        boxService.removeLadingBill(Collections.singleton(orderId));
    }
}
